@@ -67,14 +67,14 @@ class matrices:
 
         Rotate Layer Wise using temp variable :
 
+                 +---+
+            1    | 2 |     3
+                 +---+
+        +---+           +---+
+        | 4 |     8     | 9 |   -----> rotate the highlighted layer in 90 degree
+        +---+           +---+
                 +---+
-            1   | 2 |   3
-                +---+
-        +---+       +---+
-        | 4 |   8   | 9 |   -----> rotate the highlighted layer in 90 degree
-        +---+       +---+
-                +---+
-            1   | 8 |   9
+            1   | 8 |     9
                 +---+
 
         Rotate Next layer :
@@ -82,7 +82,7 @@ class matrices:
             +---+       +---+
             | 1 |   4   | 3 |
             +---+       +---+
-            8     8     2      -----> rotate the highlighted layer in 90 degree
+              8     8     2      -----> rotate the highlighted layer in 90 degree
             +---+       +---+
             | 1 |   9   | 9 |
             +---+       +---+
@@ -106,7 +106,7 @@ class matrices:
                     matrix[i][j] = 0
 
         for i in range(column):
-            if(row_arr[i]):
+            if(col_arr[i]):
                 for j in range(row):
                     matrix[j][i] = 0
 
@@ -121,7 +121,7 @@ class sorting:
                     arr[j],arr[j+1] = arr[j+1],arr[j]
                 print(arr)
         end = time.time()
-        print("Bubble Sort Runtime = {}".format(end-start))
+        print("Bubble Sort Runtime = {} seconds".format(end-start))
         if(hint == True):
             self.bubble_sort_hint()
         return arr
@@ -187,7 +187,7 @@ class sorting:
             arr[minimum],arr[i] = arr[i],arr[minimum]
             print(arr)
         end = time.time()
-        print("Selection Sort Runtime = {}".format(end-start))
+        print("Selection Sort Runtime = {} seconds".format(end-start))
         if(hint==True):
             self.selection_sort_hint()
         return arr
@@ -284,7 +284,7 @@ class sorting:
             if is_sorted(n, tmp[list(seq)], asc):
                 sorted_arr = tmp[list(seq)]
         end = time.time()
-        print("Bogo Sort Runtime = {}".format(end-start))
+        print("Bogo Sort Runtime = {} seconds".format(end-start))
 
         if hint:
             self.bogo_sort_hint()
@@ -370,7 +370,7 @@ class sorting:
             arr[j+1] = key
             print(arr)
         end = time.time()
-        print("Insertion Sort Runtime = {}".format(end-start))
+        print("Insertion Sort Runtime = {} seconds".format(end-start))
         if(hint==True):
             self.insertion_sort_hint()
         return arr
@@ -455,7 +455,7 @@ class sorting:
         start = time.time()
         result = self.merge_sort_impl(arr)
         end = time.time()
-        print("Merge Sort Runtime = {}".format(end-start))
+        print("Merge Sort Runtime = {} seconds".format(end-start))
         if(hint==True):
             self.merge_sort_hint()
         return result
@@ -533,33 +533,31 @@ class sorting:
         i = low-1
 
         for j in range(low, high):
-            if arr[j] < pivot:
+            if arr[j] <= pivot:
                 i += 1
-            arr[i], arr[j] = arr[j], arr[i]
+                arr[i], arr[j] = arr[j], arr[i]
 
         arr[i+1], arr[high] = arr[high], arr[i+1]
         return i+1
 
     # Function to perform Quick sort.
-    def quick_sort(self,arr, low, high, hint=False):
+    def quick_sort_helper(self,arr, low, high):
         if len(arr) == 1:
             return arr
         if low < high:
             partition_index = self.partition(arr, low, high)
 
-            self.quick_sort(arr, low, partition_index-1) # Before the partition index
-            self.quick_sort(arr, partition_index+1, high) # After the partition index
-
-        if hint:
-            self.quick_sort_hint()
+            self.quick_sort_helper(arr, low, partition_index-1) # Before the partition index
+            self.quick_sort_helper(arr, partition_index+1, high) # After the partition index
 
     # Helper function to call the algorithm, and calculate the computation time.
-    def quick_sort_helper(self):
-        arr = [10, 7, 8, 9, 1, 5]
+    def quick_sort(self,arr,hint=False):
+        if(hint == True):
+            self.quick_sort_hint()
         start = time.time()
-        self.quick_sort(arr, 0, len(arr)-1)
+        self.quick_sort_helper(arr, 0, len(arr)-1)
         end = time.time()
-        print("Quick Sort Runtime = {}".format(end-start))
+        print("Quick Sort Runtime = {} seconds".format(end-start))
 
     def quick_sort_hint(self):
         message = """
@@ -677,7 +675,7 @@ class sorting:
         
         print(arr)
         end = time.time()
-        print("Heap Sort Runtime = {}".format(end-start))
+        print("Heap Sort Runtime = {} seconds".format(end-start))
         if(hint == True):
             self.heap_sort_hint()
         return arr
@@ -1244,96 +1242,6 @@ class string_algorithms:
 
 class search_algorithms:
 
-    # interpolation search algorithm
-    def interpolation_search(self,array, x, hint=False):
-        # array is sorted
-        flag= -1
-        start = time.time()
-        low = 0
-        high = len(array) - 1
-        while low <= high and array[low] <= array[high]:
-            if array[low] == x:
-                flag= low
-
-            probe_pos = low + int(((float(high - low) / (array[high] - array[low])) * (x - array[low])))
-
-            if array[probe_pos] == x:
-                flag= probe_pos
-
-            if array[probe_pos] < x:
-                low = probe_pos + 1
-
-            else:
-                high = probe_pos - 1
-        end = time.time()
-        if (hint == True):
-            self.interpolation_search_hint()
-        print("Interpolation Search Runtime = {}".format(end - start))
-        return flag
-
-
-    def interpolation_search_hint(self):
-        message = """
-        Interpolation Search
-        ------------------------------------
-        Purpose : searching a required number in a sorted uniformly distributed array
-        SORTED ARRAY- Arranged in ascending order
-        Method : Searching first in the position(index) that has maximum probability of having required element.
-        Time Complexity: Best case- Ω(log(log(n)))
-                        Worst case- O(n)
-
-        Hint :
-        Starting from 0th element of array[] and comparing every element to x search one by one.
-
-        Formula used :                                (x-arr[low])
-                Probable position(pos) =   low +  ------------------- X (high-low)
-                                                (arr[high]-arr[low])
-
-                                    where low is the lowest index 
-                                        high is the highest index 
-                                        x is the number to be searched 
-                                        arr[i] is the ith element in the given sorted array 
-        Pseudocode:
-            while low<=high and array[low]<=array[high]
-                if array[low]==x
-                    return low
-                *calculate probable position(pos) with formula above
-                if array[pos]< x
-                    low = pos+1
-                if array[pos]< x
-                    high = pos-1 
-
-        Visualization:
-        Number to search => x=3
-        Given Array : arr[]
-
-    index-   0     1     2     3
-        +-----+-----+-----+-----+
-        |  1  |  3  |  4  |  6  |
-        +-----+-----+-----+-----+
-
-        First Iteration :
-        +-----+-----+-----+-----+    low = 0            high = 3
-        |  1  |  3  |  4  |  6  |    arr[low] = 1       arr[high] = 6
-        +-----+-----+-----+-----+
-        pos = 0+((3-1)/(6-3))*(3-0) = 2 
-    =>It will check at arr[pos]==x or not which is not and x<arr[pos] 
-    => low = pos+1 = 1
-
-        Second Iteration :
-        +-----+-----+-----+-----+    low = 1            high = 3
-        |  1  |  3  |  4  |  6  |    arr[low] = 3       arr[high] = 6
-        +-----+-----+-----+-----+
-        pos = 1+((3-3)/(6-3))*(3-0) = 1 
-    =>It will check at arr[pos]==x which is true 
-    => It will return 1
-
-        If no element in the array matched x=3 then it would return -1
-
-        Learn More Here - https://www.geeksforgeeks.org/interpolation-search/
-        """
-        print_msg_box(message)
-
     # linear search algorithm
     def linear_search(self,array, x, hint=False):
         start = time.time()
@@ -1389,8 +1297,10 @@ class search_algorithms:
         print_msg_box(message)
 
     #Define the bsearch method i.e. binary search
-    def bsearch(self, list, val):
+    def binary_search(self, list, val,hint=False):
 
+        if(hint == True):
+            self.binary_search_hint()
         list_size = len(list) - 1
 
         low = 0 #lower index
@@ -1412,30 +1322,29 @@ class search_algorithms:
         if low > high:
             return None
 
-    def print_bsearch_hint(self):
+    def binary_search_hint(self):
         message = """
-        FIND AN ELEMENT FROM A GIVEN SORTED LIST USING BINARY SEARCH ALGORITHM AND PRINT THE ELEMENT'S POSITION
-        -+-+-+-
+        Binary Search
+        ------------------------------------
+        Purpose : searching a required number
+        Method : Iterating, divide and conquer
+        Time Complexity: 
+        Worst-case performance: O(log n)
+        Best-case performance: O(1)
+        Average performance: O(log n)
+        Worst-case space complexity: O(1)
+        Hint :
         In binary search we take a sorted list of elements and start looking for an element at the middle of the list.
         If the search value matches with the middle value in the list we complete the search.
         Otherwise we eleminate half of the list of elements by choosing whether to procees with the right or left half
         of the list depending on the value of the item searched. This is possible as the list is sorted and it is
         much quicker than linear search. Here we divide the given list and conquer by choosing the proper half of the
         list. We repeat this approcah till we find the element or conclude about it's absence in the list.
-        -+-+-+-
         PSEUDOCODE:
             1. Compare 'x' with the middle element
             2. If x matches with the middle most element, we return the index of the middle element i.e. 'mid'.
             3. Else if x is greater than the middle element, x will lie in the right sub-part of the list from the middle element.Thus, we recur the right part of the list.
             4. Else, the x is smaller than the middle element, so we recur the left sub-part of the list.
-        -+-+-+-
-        TIME COMPLEXITY OF BINARY SEARCH ALGORITHM:
-
-            Worst-case performance: O(log n)
-            Best-case performance: O(1)
-            Average performance: O(log n)
-            Worst-case space complexity: O(1)
-        -+-+-+-
         MORE INFO HERE: https://en.wikipedia.org/wiki/Binary_search_algorithm
         """
         print_msg_box(message)
@@ -1565,4 +1474,37 @@ class greedy_algorithms:
         """
         print_msg_box(message)
 
+class recursion:
+    def step_problem(self,n,hint=False):
+        if(n <0):
+            return 0
+        if(n==0):
+            return 1
+        return self.step_problem(n-1) + self.step_problem(n-2) + self.step_problem(n-3)
 
+class dynamic_programming:
+    def step_problem(self,n,hint=False):
+        arr = [0]*(n+1)
+        arr[0] = 1
+        arr[1] = 1
+        arr[2] = 2
+        arr[3] = 4
+        for i in range(4,n+1):
+            arr[i] = arr[i-1] + arr[i-2] + arr[i-3]
+        return arr[n]
+
+
+# don't forget to add a dot for the init import before publishing the package to the PYPI
+
+# ping1 = recursion()
+# ping2 = dynamic_programming()
+
+# print(ping2.step_problem(100))
+# print(ping1.step_problem(100))
+
+# img_arr = [[1,0,3],[2,3,4],[5,6,7]]
+
+# ping = matrices()
+
+# ping.setZeros(img_arr,3,3)
+# print(img_arr)
\ No newline at end of file
